@@ -14,7 +14,12 @@ rfm <- rlmer(Reaction ~ Days + (Days|Subject) + (1|Group), sleepstudy2,
 (nmME <- eval(formals(robustlmm:::getME.rlmerMod)$name))
 for (nm in nmME) {
     cat("\nName:", nm, "\n")
-    str(getME(rfm, name=nm))
+    if (substr(nm, 1, 3) == "rho") {
+       print(getME(rfm, name=nm))
+    } else {
+       str(getME(rfm, name=nm))
+    }
 }
-str(g.all <- getME(rfm, "ALL"),
-    max.level = 2)
+g.all <- getME(rfm, "ALL")
+g.all[grepl("^rho", names(g.all))] <- NULL
+str(g.all, max.level = 2)
